@@ -29,9 +29,9 @@ public:
   /**
    * Generate a new bond vector (unit length)
    */
-  static Vector3 generateNewBondVector(const Atom& atom,
-                                       const std::vector<Vector3>& currentVectors,
-                                       AtomHybridization hybridization);
+  static Vector3 generateNewBondVector(
+    const Atom& atom, const std::vector<Vector3>& currentVectors,
+    AtomHybridization hybridization);
 
 private:
   AtomUtilities();  // Not implemented
