@@ -17,14 +17,7 @@ using std::vector;
 
 namespace Avogadro::Core {
 
-GaussianSet::GaussianSet() : m_numMOs(0), m_init(false)
-{
-  m_scfType = Rhf;
-}
-
-GaussianSet::~GaussianSet()
-{
-}
+GaussianSet::GaussianSet() : m_numMOs(0), m_init(false), m_scfType(Rhf) {}
 
 unsigned int GaussianSet::addBasis(unsigned int atom, orbital type)
 {
@@ -51,6 +44,24 @@ unsigned int GaussianSet::addBasis(unsigned int atom, orbital type)
     case F7:
       m_numMOs += 7;
       break;
+    case G:
+      m_numMOs += 15;
+      break;
+    case G9:
+      m_numMOs += 9;
+      break;
+    case H:
+      m_numMOs += 21;
+      break;
+    case H11:
+      m_numMOs += 11;
+      break;
+    case I:
+      m_numMOs += 28;
+      break;
+    case I13:
+      m_numMOs += 13;
+      break;
     default:
       // Should never hit here
       ;
@@ -143,24 +154,6 @@ bool GaussianSet::setActiveSetStep(int index)
   return true;
 }
 
-void GaussianSet::setMolecularOrbitalEnergy(const vector<double>& energies,
-                                            ElectronType type)
-{
-  if (type == Beta)
-    m_moEnergy[1] = energies;
-  else
-    m_moEnergy[0] = energies;
-}
-
-void GaussianSet::setMolecularOrbitalOccupancy(const vector<unsigned char>& occ,
-                                               ElectronType type)
-{
-  if (type == Beta)
-    m_moOccupancy[1] = occ;
-  else
-    m_moOccupancy[0] = occ;
-}
-
 void GaussianSet::setMolecularOrbitalNumber(const vector<unsigned int>& nums,
                                             ElectronType type)
 {
@@ -184,13 +177,7 @@ bool GaussianSet::setSpinDensityMatrix(const MatrixX& m)
   return true;
 }
 
-bool GaussianSet::generateDensityMatrix()
-{
-  // FIXME: Finish me!
-  return true;
-}
-
-unsigned int GaussianSet::molecularOrbitalCount(ElectronType type)
+unsigned int GaussianSet::molecularOrbitalCount(ElectronType type) const
 {
   size_t index(0);
   if (type == Beta)
@@ -447,12 +434,54 @@ void GaussianSet::initCalculation()
           m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.25) * norm); //-3
         }
       } break;
-      case G:
-        skip = 15;
-        break;
-      case G9:
-        skip = 9;
-        break;
+      case G: {
+        // 16 * (2.0/pi)^0.75
+        double norm = 11.403287525679843;
+        double norm1 = norm / sqrt(7.0);
+        double norm2 = norm / sqrt(35.0 / 3.0);
+        double norm3 = norm / sqrt(35.0);
+        m_moIndices[i] = indexMO;
+        indexMO += 15;
+        m_cIndices.push_back(static_cast<unsigned int>(m_gtoCN.size()));
+        for (unsigned j = m_gtoIndices[i]; j < m_gtoIndices[i + 1]; ++j) {
+          // molden order
+          // xxxx yyyy zzzz xxxy xxxz yyyx yyyz zzzx zzzy,
+          // xxyy xxzz yyzz xxyz yyxz zzxy
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm);  // xxxx
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm);  // yyyy
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm);  // zzzz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // xxxy
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // xxxz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // yyyx
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // yyyz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // zzzx
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm1); // zzzy
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm2); // xxyy
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm2); // xxzz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm2); // yyzz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm3); // xxyz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm3); // yyxz
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm3); // zzxy
+        }
+      } break;
+      case G9: {
+        // 16 * (2.0/pi)^0.75
+        double norm = 11.403287525679843;
+        m_moIndices[i] = indexMO;
+        indexMO += 9;
+        m_cIndices.push_back(static_cast<unsigned int>(m_gtoCN.size()));
+        for (unsigned j = m_gtoIndices[i]; j < m_gtoIndices[i + 1]; ++j) {
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); // 0
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //+1
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //-1
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //+2
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //-2
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //+3
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //-3
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //+4
+          m_gtoCN.push_back(m_gtoC[j] * pow(m_gtoA[j], 2.75) * norm); //-4
+        }
+      } break;
       case H:
         skip = 21;
         break;
@@ -479,7 +508,7 @@ void GaussianSet::initCalculation()
   m_init = true;
 }
 
-bool GaussianSet::generateDensity()
+bool GaussianSet::generateDensityMatrix()
 {
   if (m_scfType == Unknown)
     return false;
@@ -496,9 +525,11 @@ bool GaussianSet::generateDensity()
             m_density(jBasis, iBasis) += 2.0 * icoeff * jcoeff;
             m_density(iBasis, jBasis) = m_density(jBasis, iBasis);
           }
-          cout << iBasis << ", " << jBasis << ": " << m_density(iBasis, jBasis)
-               << endl;
+          //          cout << iBasis << ", " << jBasis << ": " <<
+          //          m_density(iBasis, jBasis)
+          //               << endl;
           break;
+        case Rohf: // ROHF is handled similarly to UHF
         case Uhf:
           for (unsigned int iaMO = 0; iaMO < m_electrons[0]; ++iaMO) {
             double icoeff = m_moMatrix[0](iBasis, iaMO);
@@ -512,8 +543,9 @@ bool GaussianSet::generateDensity()
             m_density(jBasis, iBasis) += icoeff * jcoeff;
             m_density(iBasis, jBasis) = m_density(jBasis, iBasis);
           }
-          cout << iBasis << ", " << jBasis << ": " << m_density(iBasis, jBasis)
-               << endl;
+          //          cout << iBasis << ", " << jBasis << ": " <<
+          //          m_density(iBasis, jBasis)
+          //               << endl;
           break;
         default:
           cout << "Unhandled scf type:" << m_scfType << endl;
@@ -523,7 +555,7 @@ bool GaussianSet::generateDensity()
   return true;
 }
 
-bool GaussianSet::generateSpinDensity()
+bool GaussianSet::generateSpinDensityMatrix()
 {
   if (m_scfType != Uhf)
     return false;
@@ -551,4 +583,4 @@ bool GaussianSet::generateSpinDensity()
   return true;
 }
 
-} // End namespace Avogadro
+} // namespace Avogadro::Core
