@@ -12,8 +12,7 @@
 
 #include <string>
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 /**
  * @class SymbolAtomTyper symbolatomtyper.h <avogadro/core/symbolatomtyper.h>
@@ -24,13 +23,12 @@ class AVOGADROCORE_EXPORT SymbolAtomTyper : public AtomTyper<std::string>
 {
 public:
   explicit SymbolAtomTyper(const Molecule* mol = nullptr);
-  ~SymbolAtomTyper() override;
+  ~SymbolAtomTyper() override = default;
 
 protected:
   std::string type(const Atom& atom) override;
 };
 
-} // namespace Core
-} // namespace Avogadro
+} // namespace Avogadro::Core
 
 #endif // AVOGADRO_CORE_SYMBOLATOMTYPER_H
