@@ -134,6 +134,12 @@ public:
    */
   Real distance(const Vector3& v1, const Vector3& v2) const;
 
+  /**
+   * @return if @a m is regular, i.e. its determinant is nonzero
+   */
+  static bool isRegular(const Matrix3& m);
+  bool isRegular() const { return isRegular(m_cellMatrix); }
+
 private:
   static Real signedAngleRadians(const Vector3& v1, const Vector3& v2,
                                  const Vector3& axis);
@@ -294,9 +300,9 @@ inline Vector3 UnitCell::wrapFractional(const Vector3& f) const
   // set anything at 1.0 to 0.0
   if (result[0] >= static_cast<Real>(0.999999))
     result[0] = static_cast<Real>(0.0);
-  if (result[1] == static_cast<Real>(0.999999))
+  if (result[1] >= static_cast<Real>(0.999999))
     result[1] = static_cast<Real>(0.0);
-  if (result[2] == static_cast<Real>(0.999999))
+  if (result[2] >= static_cast<Real>(0.999999))
     result[2] = static_cast<Real>(0.0);
 
   return result;
