@@ -8,8 +8,7 @@
 
 #include "fileformat.h"
 
-namespace Avogadro {
-namespace Io {
+namespace Avogadro::Io {
 
 /**
  * @class TrrFormat trrformat.h <avogadro/io/trrformat.h>
@@ -20,8 +19,8 @@ namespace Io {
 class AVOGADROIO_EXPORT TrrFormat : public FileFormat
 {
 public:
-  TrrFormat();
-  ~TrrFormat() override;
+  TrrFormat() = default;
+  ~TrrFormat() override = default;
 
   Operations supportedOperations() const override
   {
@@ -45,10 +44,11 @@ public:
   std::vector<std::string> mimeTypes() const override;
 
   bool read(std::istream& inStream, Core::Molecule& molecule) override;
+
+  // uninplemented
   bool write(std::ostream& outStream, const Core::Molecule& molecule) override;
 };
 
-} // end Io namespace
-} // end Avogadro namespace
+} // namespace Avogadro::Io
 
 #endif // AVOGADRO_IO_TRRFORMAT_H
