@@ -81,6 +81,10 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
 
   string buffer;
   getline(inStream, buffer); // Finish the first line
+  if (!inStream.good()) {
+    appendError("Error reading first line.");
+    return false;
+  }
   getline(inStream, buffer); // comment or name or energy
   if (!buffer.empty())
     mol.setData("name", trimmed(buffer));
@@ -96,15 +100,23 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
   // e.g. Lattice="H11 H21 H31 H12 H22 H32 H13 H23 H33"
   // https://atomsk.univ-lille.fr/doc/en/format_xyz.html
   // https://gitlab.com/ase/ase/-/merge_requests/62
-  std::size_t start = buffer.find("Lattice=\"");
+  std::size_t start = buffer.find("Lattice=");
   if (start != std::string::npos) {
     // step through bit by bit until we hit the next quote character
-    start = start + 9;
+    start = start + 8;
+    // skip over the first quote
+    if (buffer[start] == '\"') {
+      start++;
+    }
     std::size_t end = buffer.find('\"', start);
     std::string lattice = buffer.substr(start, (end - start));
 
     std::vector<string> tokens(split(lattice, ' '));
-    if (tokens.size() == 9) {
+
+    // check for size
+    std::cout << "Lattice size: " << tokens.size() << std::endl;
+
+    if (tokens.size() >= 9) {
       Vector3 v1(lexicalCast<double>(tokens[0]), lexicalCast<double>(tokens[1]),
                  lexicalCast<double>(tokens[2]));
       Vector3 v2(lexicalCast<double>(tokens[3]), lexicalCast<double>(tokens[4]),
@@ -113,7 +125,14 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
                  lexicalCast<double>(tokens[8]));
 
       auto* cell = new Core::UnitCell(v1, v2, v3);
-      mol.setUnitCell(cell);
+      std::cout << " Lattice: " << cell->aVector() << " " << cell->bVector()
+                << " " << cell->cVector() << std::endl;
+      if (!cell->isRegular()) {
+        appendError("Lattice vectors are not linear independent");
+        delete cell;
+      } else {
+        mol.setUnitCell(cell);
+      }
     }
   }
   // check to see if there's an extended XYZ Properties= line
@@ -147,9 +166,19 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
     }
   }
 
+  if (!inStream.good()) {
+    appendError("Error reading comment line.");
+    return false;
+  }
+
   // Parse atoms
   for (size_t i = 0; i < numAtoms; ++i) {
     getline(inStream, buffer);
+    if (!inStream.good()) {
+      appendError("Error reading atom at index " + std::to_string(i) + ".");
+      return false;
+    }
+
     std::vector<string> tokens;
     // check for tabs PR#1512
     if (buffer.find('\t') != std::string::npos)
@@ -346,6 +375,7 @@ std::vector<std::string> XyzFormat::fileExtensions() const
   ext.emplace_back("xyz");
   ext.emplace_back("exyz");
   ext.emplace_back("extxyz");
+  ext.emplace_back("allxyz");
   return ext;
 }
 
