@@ -9,26 +9,22 @@
 
 namespace Avogadro::MoleQueue {
 
-JobObject::JobObject()
-{
-}
+JobObject::JobObject() {}
 
-JobObject::~JobObject()
-{
-}
+JobObject::~JobObject() {}
 
-void JobObject::setValue(const QString &key, const QVariant &value_)
+void JobObject::setValue(const QString& key, const QVariant& value_)
 {
   m_value[key] = QJsonValue::fromVariant(value_);
 }
 
-QVariant JobObject::value(const QString &key,
-                          const QVariant &defaultValue) const
+QVariant JobObject::value(const QString& key,
+                          const QVariant& defaultValue) const
 {
   return m_value.contains(key) ? m_value[key].toVariant() : defaultValue;
 }
 
-void JobObject::setQueue(const QString &queueName)
+void JobObject::setQueue(const QString& queueName)
 {
   m_value["queue"] = queueName;
 }
@@ -38,7 +34,7 @@ QString JobObject::queue() const
   return m_value["queue"].toString();
 }
 
-void JobObject::setProgram(const QString &programName)
+void JobObject::setProgram(const QString& programName)
 {
   m_value["program"] = programName;
 }
@@ -48,7 +44,7 @@ QString JobObject::program() const
   return m_value["program"].toString();
 }
 
-void JobObject::setDescription(const QString &descriptionText)
+void JobObject::setDescription(const QString& descriptionText)
 {
   m_value["description"] = descriptionText;
 }
@@ -58,17 +54,17 @@ QString JobObject::description() const
   return m_value["description"].toString();
 }
 
-void JobObject::setInputFile(const QString &fileName, const QString &contents)
+void JobObject::setInputFile(const QString& fileName, const QString& contents)
 {
   m_value["inputFile"] = fileSpec(fileName, contents);
 }
 
-void JobObject::setInputFile(const QString &path)
+void JobObject::setInputFile(const QString& path)
 {
   m_value["inputFile"] = fileSpec(path);
 }
 
-void JobObject::setInputFile(const QJsonObject &file)
+void JobObject::setInputFile(const QJsonObject& file)
 {
   m_value["inputFile"] = file;
 }
@@ -78,8 +74,8 @@ QJsonObject JobObject::inputFile() const
   return m_value["inputFile"].toObject();
 }
 
-void JobObject::appendAdditionalInputFile(const QString &fileName,
-                                          const QString &contents)
+void JobObject::appendAdditionalInputFile(const QString& fileName,
+                                          const QString& contents)
 {
   QJsonArray extraInputFiles;
   if (m_value["additionalInputFiles"].isArray())
@@ -88,7 +84,7 @@ void JobObject::appendAdditionalInputFile(const QString &fileName,
   m_value["additionalInputFiles"] = extraInputFiles;
 }
 
-void JobObject::appendAdditionalInputFile(const QString &path)
+void JobObject::appendAdditionalInputFile(const QString& path)
 {
   QJsonArray extraInputFiles;
   if (m_value["additionalInputFiles"].isArray())
@@ -97,7 +93,7 @@ void JobObject::appendAdditionalInputFile(const QString &path)
   m_value["additionalInputFiles"] = extraInputFiles;
 }
 
-void JobObject::setAdditionalInputFiles(const QJsonArray &files)
+void JobObject::setAdditionalInputFiles(const QJsonArray& files)
 {
   m_value["additionalInputFiles"] = files;
 }
@@ -112,7 +108,8 @@ QJsonArray JobObject::additionalInputFiles() const
   return m_value["additionalInputFiles"].toArray();
 }
 
-QJsonObject JobObject::fileSpec(const QString &fileName, const QString &contents)
+QJsonObject JobObject::fileSpec(const QString& fileName,
+                                const QString& contents)
 {
   QJsonObject result;
   result["filename"] = fileName;
@@ -120,11 +117,11 @@ QJsonObject JobObject::fileSpec(const QString &fileName, const QString &contents
   return result;
 }
 
-QJsonObject JobObject::fileSpec(const QString &path)
+QJsonObject JobObject::fileSpec(const QString& path)
 {
   QJsonObject result;
   result["path"] = path;
   return result;
 }
 
-} // End namespace Avogadro
+} // namespace Avogadro::MoleQueue
