@@ -85,4 +85,4 @@ bool ColorButton::event(QEvent* e)
   return QAbstractButton::event(e);
 }
 
-} // namespace Avogadro
\ No newline at end of file
+} // namespace Avogadro::QtGui
\ No newline at end of file
