@@ -13,10 +13,8 @@
 namespace Avogadro::QtGui {
 
 ContainerWidget::ContainerWidget(QWidget* p, Qt::WindowFlags f)
-  : QWidget(p, f)
-  , m_viewWidget(nullptr)
-  , m_label(new QLabel(QStringLiteral("   "), this))
-  , m_active(false)
+  : QWidget(p, f), m_viewWidget(nullptr),
+    m_label(new QLabel(QStringLiteral("   "), this)), m_active(false)
 {
   auto* h = new QHBoxLayout;
   h->setContentsMargins(0, 0, 0, 0);
@@ -62,4 +60,4 @@ void ContainerWidget::setActive(bool active)
   }
 }
 
-} // End Avogadro namespace
+} // namespace Avogadro::QtGui
