@@ -18,6 +18,8 @@ AVOGADROQTGUI_EXPORT QString libraryDirectory();
 AVOGADROQTGUI_EXPORT QString dataDirectory();
 //! \return a fully-qualified path for a program or an empty string if not found
 AVOGADROQTGUI_EXPORT QString findExecutablePath(QString program);
+//! \return a list of all fully-qualified paths for programs that are found
+AVOGADROQTGUI_EXPORT QStringList findExecutablePaths(QStringList programs);
 
 } // namespace Utilities
 } // namespace QtGui
