@@ -15,13 +15,13 @@
 
 #include <avogadro/rendering/camera.h>
 
+#include <QAction>
 #include <QtCore/QTimer>
 #include <QtGui/QKeyEvent>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QWheelEvent>
-#include <QAction>
-#include <QtWidgets/QApplication>
 #include <QtGui/QWindow>
+#include <QtWidgets/QApplication>
 
 namespace Avogadro::QtOpenGL {
 
@@ -30,10 +30,10 @@ GLWidget::GLWidget(QWidget* p)
     m_renderTimer(nullptr)
 {
   setFocusPolicy(Qt::ClickFocus);
-  connect(&m_scenePlugins,
-          SIGNAL(pluginStateChanged(Avogadro::QtGui::ScenePlugin*)),
-          SLOT(updateScene()));
-  connect(&m_scenePlugins, SIGNAL(pluginConfigChanged()), SLOT(updateScene()));
+  connect(&m_scenePlugins, &QtGui::ScenePluginModel::pluginStateChanged, this,
+          &GLWidget::updateScene);
+  connect(&m_scenePlugins, &QtGui::ScenePluginModel::pluginConfigChanged, this,
+          &GLWidget::updateScene);
   m_renderer.setTextRenderStrategy(new QtTextRenderStrategy);
 }
 
@@ -47,7 +47,13 @@ void GLWidget::setMolecule(QtGui::Molecule* mol)
   m_molecule = mol;
   foreach (QtGui::ToolPlugin* tool, m_tools)
     tool->setMolecule(m_molecule);
-  connect(m_molecule, SIGNAL(changed(unsigned int)), SLOT(updateScene()));
+
+  if (m_molecule != nullptr) {
+    // update properties like dipole rendering
+    QTimer::singleShot(500, m_molecule, &QtGui::Molecule::update);
+  }
+
+  connect(m_molecule, &QtGui::Molecule::changed, this, &GLWidget::updateScene);
 }
 
 QtGui::Molecule* GLWidget::molecule()
@@ -60,6 +66,14 @@ const QtGui::Molecule* GLWidget::molecule() const
   return m_molecule;
 }
 
+void GLWidget::updateMolecule()
+{
+  if (m_molecule != nullptr) {
+    // update properties like dipole rendering
+    QTimer::singleShot(500, m_molecule, &QtGui::Molecule::update);
+  }
+}
+
 void GLWidget::updateScene()
 {
   // Build up the scene with the scene plugins, creating the appropriate nodes.
@@ -124,7 +138,8 @@ void GLWidget::addTool(QtGui::ToolPlugin* tool)
   if (m_tools.contains(tool))
     return;
 
-  connect(tool, SIGNAL(updateRequested()), SLOT(requestUpdate()));
+  connect(tool, &QtGui::ToolPlugin::updateRequested, this,
+          &GLWidget::requestUpdate);
   tool->setParent(this);
   tool->setGLWidget(this);
   tool->setActiveWidget(this);
@@ -151,8 +166,8 @@ void GLWidget::setActiveTool(QtGui::ToolPlugin* tool)
     return;
 
   if (m_activeTool && m_activeTool != m_defaultTool) {
-    disconnect(m_activeTool, SIGNAL(drawablesChanged()), this,
-               SLOT(updateScene()));
+    disconnect(m_activeTool, &QtGui::ToolPlugin::drawablesChanged, this,
+               &GLWidget::updateScene);
   }
 
   if (tool)
@@ -160,8 +175,8 @@ void GLWidget::setActiveTool(QtGui::ToolPlugin* tool)
   m_activeTool = tool;
 
   if (m_activeTool && m_activeTool != m_defaultTool) {
-    connect(m_activeTool, SIGNAL(drawablesChanged()), this,
-            SLOT(updateScene()));
+    connect(m_activeTool, &QtGui::ToolPlugin::drawablesChanged, this,
+            &GLWidget::updateScene);
   }
 }
 
@@ -169,7 +184,9 @@ void GLWidget::setDefaultTool(const QString& name)
 {
   foreach (QtGui::ToolPlugin* tool, m_tools) {
     QAction* toolAction = tool->activateAction();
-    if (tool->name() == name || (toolAction && toolAction->text() == name)) {
+
+    if (tool->objectName() == name || tool->name() == name ||
+        (toolAction && toolAction->text() == name)) {
       setDefaultTool(tool);
       return;
     }
@@ -182,8 +199,8 @@ void GLWidget::setDefaultTool(QtGui::ToolPlugin* tool)
     return;
 
   if (m_defaultTool && m_activeTool != m_defaultTool) {
-    disconnect(m_defaultTool, SIGNAL(drawablesChanged()), this,
-               SLOT(updateScene()));
+    disconnect(m_defaultTool, &QtGui::ToolPlugin::drawablesChanged, this,
+               &GLWidget::updateScene);
   }
 
   if (tool)
@@ -191,8 +208,8 @@ void GLWidget::setDefaultTool(QtGui::ToolPlugin* tool)
   m_defaultTool = tool;
 
   if (m_defaultTool && m_activeTool != m_defaultTool) {
-    connect(m_defaultTool, SIGNAL(drawablesChanged()), this,
-            SLOT(updateScene()));
+    connect(m_defaultTool, &QtGui::ToolPlugin::drawablesChanged, this,
+            &GLWidget::updateScene);
   }
 }
 
@@ -200,8 +217,8 @@ void GLWidget::requestUpdate()
 {
   if (!m_renderTimer) {
     m_renderTimer = new QTimer(this);
-    connect(m_renderTimer, SIGNAL(timeout()), SLOT(updateTimeout()));
-    m_renderTimer->setSingleShot(1000 / 30);
+    connect(m_renderTimer, &QTimer::timeout, this, &GLWidget::updateTimeout);
+    m_renderTimer->setSingleShot(1000 / 30); // 30 fps
     m_renderTimer->start();
   }
 }
@@ -332,4 +349,4 @@ void GLWidget::keyReleaseEvent(QKeyEvent* e)
     QOpenGLWidget::keyReleaseEvent(e);
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtOpenGL
