@@ -171,7 +171,7 @@ void ApbsDialog::runPdb2Pqr()
 void ApbsDialog::saveInputFile()
 {
   QString fileName = QFileDialog::getSaveFileName(
-    this, tr("Save APBS Input File"), "apbs.in", tr("ABPS Input (*.in)"));
+    this, tr("Save APBS Input File"), "apbs.in", tr("APBS Input (*.in)"));
   if (!fileName.isEmpty()) {
     saveInputFile(fileName);
 
@@ -218,4 +218,4 @@ void ApbsDialog::updatePreviewTextImmediately()
 
   m_ui->textEdit->setText(m_inputGenerator->fileContents("apbs.in"));
 }
-}
+} // namespace Avogadro::QtPlugins
