@@ -117,14 +117,15 @@ BondCentricTool::BondCentricTool(QObject* parent_)
   QString shortcut = tr("Ctrl+7", "control-key 7");
   m_activateAction->setText(tr("Bond-Centric Manipulation"));
   m_activateAction->setToolTip(
-    tr("Bond Centric Manipulation Tool \t(%1)\n\n"
-       "Left Mouse: \tClick and drag to rotate the view.\n"
-       "Middle Mouse: \tClick and drag to zoom in or out.\n"
-       "Right Mouse: \tClick and drag to move the view.\n"
-       "Double-Click: \tReset the view.\n\n"
-       "Left Click & Drag on a Bond to set the Manipulation Plane:\n"
+    tr("Bond Centric Manipulation Tool\t(%1)\n\n"
+       "Left Mouse:\tClick and drag to rotate the view.\n"
+       "Middle Mouse:\tClick and drag to zoom in or out.\n"
+       "Right Mouse:\tClick and drag to move the view.\n"
+       "Double-Click:\tReset the view.\n\n"
+       "Left Click & Drag on a Bond to set the Manipulation Plane\n"
        "Left Click & Drag one of the Atoms in the Bond to change the angle\n"
-       "Right Click & Drag one of the Atoms in the Bond to change the length").arg(shortcut));
+       "Right Click & Drag one of the Atoms in the Bond to change the length")
+      .arg(shortcut));
   setIcon();
 }
 
@@ -1031,7 +1032,7 @@ bool BondCentricTool::buildFragmentRecurse(const QtGui::RWBond& bond,
         return false;
       }
     } // *it != bond
-  }   // foreach bond
+  } // foreach bond
   return true;
 }
 
