@@ -91,4 +91,4 @@ void ComDialog::setOpacity(double value)
   }
 }
 
-} // namespace Avogadro
\ No newline at end of file
+} // namespace Avogadro::QtPlugins
\ No newline at end of file
