@@ -8,11 +8,11 @@
 #include <avogadro/io/fileformatmanager.h>
 #include <avogadro/qtgui/molecule.h>
 
+#include <QAction>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
 #include <QtNetwork/QNetworkAccessManager>
 #include <QtNetwork/QNetworkReply>
-#include <QAction>
 #include <QtWidgets/QInputDialog>
 #include <QtWidgets/QMessageBox>
 #include <QtWidgets/QProgressDialog>
@@ -52,7 +52,7 @@ bool FetchPDB::readMolecule(QtGui::Molecule& mol)
     return false;
 
   bool readOK = Io::FileFormatManager::instance().readFile(
-    mol, m_tempFileName.toStdString(), "mmtf");
+    mol, m_tempFileName.toStdString(), "pdb");
   if (readOK) // worked, so set the filename
     mol.setData("name", m_moleculeName.toStdString());
   else
@@ -66,14 +66,6 @@ bool FetchPDB::readMolecule(QtGui::Molecule& mol)
 
 void FetchPDB::showDialog()
 {
-  if (!m_network) {
-    m_network = new QNetworkAccessManager(this);
-    connect(m_network, SIGNAL(finished(QNetworkReply*)), this,
-            SLOT(replyFinished(QNetworkReply*)));
-  }
-  if (!m_progressDialog) {
-    m_progressDialog = new QProgressDialog(qobject_cast<QWidget*>(parent()));
-  }
   // Prompt for a chemical structure name
   bool ok;
   QString pdbCode = QInputDialog::getText(
@@ -83,11 +75,35 @@ void FetchPDB::showDialog()
   if (!ok || pdbCode.isEmpty())
     return;
 
+  // check if the PDB code matches the expected format
+  if (pdbCode.length() != 4) {
+    QMessageBox::warning(qobject_cast<QWidget*>(parent()),
+                         tr("Invalid PDB Code"),
+                         tr("The PDB code must be exactly 4 characters long."));
+    return;
+  }
+
+  // first character should be 1-9
+  if (!pdbCode.at(0).isDigit() || pdbCode.at(0).toLatin1() == '0') {
+    QMessageBox::warning(
+      qobject_cast<QWidget*>(parent()), tr("Invalid PDB Code"),
+      tr("The first character of the PDB code must be 1-9."));
+    return;
+  }
+
+  if (!m_network) {
+    m_network = new QNetworkAccessManager(this);
+    connect(m_network, SIGNAL(finished(QNetworkReply*)), this,
+            SLOT(replyFinished(QNetworkReply*)));
+  }
+
   // Hard coding the PDB download URL
   m_network->get(QNetworkRequest(
-    //    QUrl("https://files.rcsb.org/download/" + pdbCode + ".pdb")));
-    // prefer MMTF - smaller and more efficient (also could use .mmtf.gz)
-    QUrl("https://mmtf.rcsb.org/v1.0/full/" + pdbCode)));
+    QUrl("https://files.rcsb.org/download/" + pdbCode + ".pdb")));
+
+  if (!m_progressDialog) {
+    m_progressDialog = new QProgressDialog(qobject_cast<QWidget*>(parent()));
+  }
 
   m_moleculeName = pdbCode;
   m_progressDialog->setLabelText(tr("Querying for %1").arg(pdbCode));
@@ -108,15 +124,10 @@ void FetchPDB::replyFinished(QNetworkReply* reply)
   }
 
   m_moleculeData = reply->readAll();
-  m_tempFileName =
-    QDir::tempPath() + QDir::separator() + m_moleculeName + ".mmtf";
-  QFile out(m_tempFileName);
-  out.open(QIODevice::WriteOnly);
-  out.write(m_moleculeData);
-  out.close();
 
   // Check if the file was successfully downloaded
-  if (m_moleculeData.contains("Error report") ||
+  if (m_moleculeData.contains("Not Found") ||
+      m_moleculeData.contains("Error report") ||
       m_moleculeData.contains("Page not found (404)")) {
     QMessageBox::warning(
       qobject_cast<QWidget*>(parent()), tr("Network Download Failed"),
@@ -124,7 +135,16 @@ void FetchPDB::replyFinished(QNetworkReply* reply)
     reply->deleteLater();
     return;
   }
+
+  m_tempFileName =
+    QDir::tempPath() + QDir::separator() + m_moleculeName + ".pdb";
+  QFile out(m_tempFileName);
+  out.open(QIODevice::WriteOnly);
+  out.write(m_moleculeData);
+  out.close();
+
   emit moleculeReady(1);
   reply->deleteLater();
 }
-} // namespace Avogadro
+
+} // namespace Avogadro::QtPlugins
