@@ -26,8 +26,8 @@ using Avogadro::QtGui::Molecule;
 namespace Avogadro::QtPlugins {
 
 InsertFragment::InsertFragment(QObject* parent_)
-  : Avogadro::QtGui::ExtensionPlugin(parent_), m_crystalDialog(nullptr),
-    m_moleculeDialog(nullptr), m_reader(nullptr), m_molecule(nullptr)
+  : Avogadro::QtGui::ExtensionPlugin(parent_), m_moleculeDialog(nullptr),
+    m_crystalDialog(nullptr), m_molecule(nullptr), m_reader(nullptr)
 {
   auto* action = new QAction(tr("Molecule…"), this);
   action->setProperty("menu priority", 890);
