@@ -19,7 +19,7 @@ public:
   //! Constructor
   explicit ConformerSearchDialog(QWidget* parent = 0);
   //! Deconstructor
-  ~ConformerSearchDialog();
+  ~ConformerSearchDialog() override;
 
   int method();
   int numConformers();
@@ -27,8 +27,8 @@ public:
   QStringList options() const;
 
 public slots:
-  void accept();
-  void reject();
+  void accept() override;
+  void reject() override;
   void systematicToggled(bool checked);
   void randomToggled(bool checked);
   void weightedToggled(bool checked);
