@@ -16,18 +16,18 @@ class OBCharges : public Avogadro::Calc::ChargeModel
 {
 public:
   OBCharges(const std::string& identifier = "");
-  virtual ~OBCharges();
+  ~OBCharges() override;
 
   /**
    * Create a new instance of the file format class. Ownership passes to the
    * caller.
    */
-  virtual OBCharges* newInstance() const override { return new OBCharges; }
+  OBCharges* newInstance() const override { return new OBCharges; }
 
   /**
    * @brief A unique identifier defined by the file
    */
-  virtual std::string identifier() const override { return m_identifier; }
+  std::string identifier() const override { return m_identifier; }
 
   /**
    * @brief Set the identifier
@@ -40,22 +40,19 @@ public:
   /**
    * @brief Based on the identifiers -- for the menus, etc.
    */
-  virtual std::string name() const override;
+  std::string name() const override;
 
   /**
    * @brief The element mask for a particular OB charge model (e.g., Gasteiger)
    * @return the mask relevant for this method
    */
-  virtual Core::Molecule::ElementMask elements() const override
-  {
-    return m_elements;
-  }
+  Core::Molecule::ElementMask elements() const override { return m_elements; }
 
   /**
    * @brief Retrieve the relevant charges from the molecule for our defined type
    */
-  virtual MatrixX partialCharges(Core::Molecule& mol) const override;
-  virtual MatrixX partialCharges(const Core::Molecule& mol) const override;
+  MatrixX partialCharges(Core::Molecule& mol) const override;
+  MatrixX partialCharges(const Core::Molecule& mol) const override;
 
   /**
    * @brief Synchronous use of the OBProcess.
