@@ -33,15 +33,15 @@ class PlotXrd : public Avogadro::QtGui::ExtensionPlugin
   Q_OBJECT
 public:
   explicit PlotXrd(QObject* parent_ = nullptr);
-  ~PlotXrd();
+  ~PlotXrd() override;
 
-  QString name() const { return tr("PlotXrd"); }
-  QString description() const;
-  QList<QAction*> actions() const;
-  QStringList menuPath(QAction*) const;
+  QString name() const override { return tr("PlotXrd"); }
+  QString description() const override;
+  QList<QAction*> actions() const override;
+  QStringList menuPath(QAction*) const override;
 
 public slots:
-  void setMolecule(QtGui::Molecule* mol);
+  void setMolecule(QtGui::Molecule* mol) override;
 
   void moleculeChanged(unsigned int changes);
 
