@@ -62,4 +62,4 @@ void XrdOptionsDialog::accept()
   QDialog::accept();
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtPlugins
