@@ -19,8 +19,7 @@
 namespace Avogadro::QtPlugins {
 
 PluginManager::PluginManager(QObject* p)
-  : QObject(p)
-  , m_staticPluginsLoaded(false)
+  : QObject(p), m_staticPluginsLoaded(false)
 {
   QString libDir(QtGui::Utilities::libraryDirectory());
   // http://doc.qt.digia.com/qt/deployment-plugins.html#debugging-plugins
@@ -125,4 +124,4 @@ void PluginManager::load(const QString& path)
   }
 }
 
-} // End Avogadro namespace
+} // namespace Avogadro::QtPlugins
