@@ -51,7 +51,7 @@ const int ResidueColumns = 6;
 const int ConformerColumns = 1;
 
 // compute the RMSD between the two sets of coordinates
-inline double calcRMSD(const Array<Vector3>& v1, const Array<Vector3>& v2)
+inline double calculateRMSD(const Array<Vector3>& v1, const Array<Vector3>& v2)
 {
   // if they're not the same length, it's an error
   if (v1.size() != v2.size())
@@ -305,14 +305,26 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
       case AtomDataPartialCharge:
         return partialCharge(m_molecule, row);
       case AtomDataX:
-        return QString("%L1").arg(m_molecule->atomPosition3d(row).x(), 0, 'f',
-                                  4);
+        if (role == Qt::UserRole)
+          // Return the x coordinate as a double for sorting
+          return m_molecule->atomPosition3d(row).x();
+        else // format fixed to 4 decimals
+          return QString("%L1").arg(m_molecule->atomPosition3d(row).x(), 0, 'f',
+                                    4);
       case AtomDataY:
-        return QString("%L1").arg(m_molecule->atomPosition3d(row).y(), 0, 'f',
-                                  4);
+        if (role == Qt::UserRole)
+          // Return the y coordinate as a double for sorting
+          return m_molecule->atomPosition3d(row).y();
+        else // format fixed to 4 decimals
+          return QString("%L1").arg(m_molecule->atomPosition3d(row).y(), 0, 'f',
+                                    4);
       case AtomDataZ:
-        return QString("%L1").arg(m_molecule->atomPosition3d(row).z(), 0, 'f',
-                                  4);
+        if (role == Qt::UserRole)
+          // Return the z coordinate as a double for sorting
+          return m_molecule->atomPosition3d(row).z();
+        else // format fixed to 4 decimals
+          return QString("%L1").arg(m_molecule->atomPosition3d(row).z(), 0, 'f',
+                                    4);
       case AtomDataLabel:
         return m_molecule->atomLabel(row).c_str();
       case AtomDataColor:
@@ -346,8 +358,12 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
       case BondDataLabel:
         return m_molecule->bondLabel(row).c_str();
       default: // length, rounded to 4 decimals
-        return QString("%L1 Å").arg(
-          distance(atom1.position3d(), atom2.position3d()), 0, 'f', 3);
+        if (role == Qt::UserRole)
+          // Return the bond length as a double for sorting
+          return distance(atom1.position3d(), atom2.position3d());
+        else
+          return QString("%L1 Å").arg(
+            distance(atom1.position3d(), atom2.position3d()), 0, 'f', 3);
     }
   } else if (m_type == ResidueType) {
 
@@ -400,7 +416,11 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
       case AngleDataAtom3:
         return QVariant::fromValue(std::get<2>(angle) + 1);
       case AngleDataValue:
-        return QString("%L1 °").arg(calcAngle(a1, a2, a3), 0, 'f', 3);
+        if (role == Qt::UserRole)
+          // Return the angle as a double for sorting
+          return calculateAngle(a1, a2, a3);
+        else // format fixed to 3 decimals
+          return QString("%L1 °").arg(calculateAngle(a1, a2, a3), 0, 'f', 3);
       default:
         return QVariant();
     }
@@ -436,7 +456,12 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
       case TorsionDataAtom4:
         return QVariant::fromValue(std::get<3>(torsion) + 1);
       case TorsionDataValue:
-        return QString("%L1 °").arg(calcDihedral(a1, a2, a3, a4), 0, 'f', 3);
+        if (role == Qt::UserRole)
+          // Return the dihedral angle as a double for sorting
+          return calculateDihedral(a1, a2, a3, a4);
+        else // format fixed to 3 decimals
+          return QString("%L1 °").arg(calculateDihedral(a1, a2, a3, a4), 0, 'f',
+                                      3);
       default:
         return QVariant();
     }
@@ -451,11 +476,14 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
       case ConformerDataRMSD: { // rmsd
         double rmsd = 0.0;
         if (row > 0) {
-          rmsd = calcRMSD(m_molecule->coordinate3d(row),
-                          m_molecule->coordinate3d(0));
+          rmsd = calculateRMSD(m_molecule->coordinate3d(row),
+                               m_molecule->coordinate3d(0));
         }
-
-        return QString("%L1 Å").arg(rmsd, 0, 'f', 3);
+        if (role == Qt::UserRole)
+          // Return the RMSD as a double for sorting
+          return rmsd;
+        else // format fixed to 3 decimals
+          return QString("%L1 Å").arg(rmsd, 0, 'f', 3);
       }
       case ConformerDataEnergy: {
         double energy = 0.0;
@@ -469,7 +497,11 @@ QVariant PropertyModel::data(const QModelIndex& index, int role) const
           if (row < static_cast<int>(energies.size()))
             energy = energies[row] - minEnergy;
         }
-        return QString("%L1").arg(energy, 0, 'f', 4);
+        if (role == Qt::UserRole)
+          // Return the energy as a double for sorting
+          return energy;
+        else // format fixed to 4 decimals
+          return QString("%L1").arg(energy, 0, 'f', 4);
       }
     }
   }
@@ -856,7 +888,7 @@ void PropertyModel::setAngle(unsigned int index, double newValue)
   Vector3 a = atom1.position3d();
   Vector3 b = atom2.position3d();
   Vector3 c = atom3.position3d();
-  const double currentValue = calcAngle(a, b, c);
+  const double currentValue = calculateAngle(a, b, c);
   Vector3 ab = b - a;
   Vector3 bc = c - b;
 
@@ -893,7 +925,7 @@ void PropertyModel::setTorsion(unsigned int index, double newValue)
   Vector3 b = atom2.position3d();
   Vector3 c = atom3.position3d();
   Vector3 d = atom4.position3d();
-  const double currentValue = calcDihedral(a, b, c, d);
+  const double currentValue = calculateDihedral(a, b, c, d);
 
   // Axis of rotation
   const Vector3 axis((c - b).normalized());
@@ -999,6 +1031,21 @@ Core::Angle PropertyModel::getAngle(unsigned int angle) const
   return m_angles[angle];
 }
 
+Real PropertyModel::getAngleValue(unsigned int angle) const
+{
+  if (angle >= m_angles.size())
+    return 0.0;
+
+  auto a = m_angles[angle];
+  auto atom1 = m_molecule->undoMolecule()->atom(std::get<0>(a));
+  auto atom2 = m_molecule->undoMolecule()->atom(std::get<1>(a));
+  auto atom3 = m_molecule->undoMolecule()->atom(std::get<2>(a));
+  Vector3 a1 = atom1.position3d();
+  Vector3 a2 = atom2.position3d();
+  Vector3 a3 = atom3.position3d();
+  return calculateAngle(a1, a2, a3);
+}
+
 Core::Dihedral PropertyModel::getTorsion(unsigned int torsion) const
 {
   if (torsion >= m_torsions.size())
@@ -1007,4 +1054,21 @@ Core::Dihedral PropertyModel::getTorsion(unsigned int torsion) const
   return m_torsions[torsion];
 }
 
+Real PropertyModel::getTorsionValue(unsigned int torsion) const
+{
+  if (torsion >= m_torsions.size())
+    return 0.0;
+
+  auto t = m_torsions[torsion];
+  auto atom1 = m_molecule->undoMolecule()->atom(std::get<0>(t));
+  auto atom2 = m_molecule->undoMolecule()->atom(std::get<1>(t));
+  auto atom3 = m_molecule->undoMolecule()->atom(std::get<2>(t));
+  auto atom4 = m_molecule->undoMolecule()->atom(std::get<3>(t));
+  Vector3 a1 = atom1.position3d();
+  Vector3 a2 = atom2.position3d();
+  Vector3 a3 = atom3.position3d();
+  Vector3 a4 = atom4.position3d();
+  return calculateDihedral(a1, a2, a3, a4);
+}
+
 } // end namespace Avogadro
