@@ -705,10 +705,14 @@ static int rule15gauss_evalError(rule* r, unsigned int fdim, integrand_v f,
   const unsigned int n = 8;
   const double xgk[8] = {
     /* abscissae of the 15-point kronrod rule */
-    0.991455371120812639206854697526329, 0.949107912342758524526189684047851,
-    0.864864423359769072789712788640926, 0.741531185599394439863864773280788,
-    0.586087235467691130294144838258730, 0.405845151377397166906606412076961,
-    0.207784955007898467600689403773245, 0.000000000000000000000000000000000
+    0.991455371120812639206854697526329,
+    0.949107912342758524526189684047851,
+    0.864864423359769072789712788640926,
+    0.741531185599394439863864773280788,
+    0.586087235467691130294144838258730,
+    0.405845151377397166906606412076961,
+    0.207784955007898467600689403773245,
+    0.000000000000000000000000000000000
     /* xgk[1], xgk[3], ... abscissae of the 7-point gauss rule.
        xgk[0], xgk[2], ... to optimally extend the 7-point gauss rule */
   };
@@ -1245,7 +1249,7 @@ QList<QVariant> QTAIMEvaluateProperty(QList<QVariant> variantList)
     counter++;
     basinList.append(basin);
   }
-  QSet<qint64> basinSet = basinList.toSet();
+  QSet<qint64> basinSet(basinList.begin(), basinList.end());
 
   QTAIMWavefunction wfn;
   wfn.loadFromBinaryFile(wfnFileName);
@@ -1279,7 +1283,7 @@ QList<QVariant> QTAIMEvaluateProperty(QList<QVariant> variantList)
     ode.setBetaSpheres(betaSpheres);
 
     QVector3D endpoint = ode.integrate(QVector3D(x0, y0, z0));
-// QList<QVector3D> path=ode.path();
+    // QList<QVector3D> path=ode.path();
 
 #define HUGE_REAL_NUMBER 1.e20
     qreal smallestDistance = HUGE_REAL_NUMBER;
@@ -1407,7 +1411,7 @@ void property_v(unsigned int /* ndim */, unsigned int npts, const double* xyz,
   dialog.setWindowTitle("QTAIM");
   dialog.setLabelText(QString("Atomic Basin Integration"));
 
-  QFutureWatcher<void> futureWatcher;
+  QFutureWatcher<QList<QVariant>> futureWatcher;
   QObject::connect(&futureWatcher, SIGNAL(finished()), &dialog, SLOT(reset()));
   QObject::connect(&dialog, SIGNAL(canceled()), &futureWatcher, SLOT(cancel()));
   QObject::connect(&futureWatcher, SIGNAL(progressRangeChanged(int, int)),
@@ -1505,7 +1509,7 @@ QList<QVariant> QTAIMEvaluatePropertyRTP(QList<QVariant> variantList)
     counter++;
     basinList.append(basin);
   }
-  QSet<qint64> basinSet = basinList.toSet();
+  QSet<qint64> basinSet(basinList.begin(), basinList.end());
 
   Matrix<qreal, 3, 1> r0t0p0;
   r0t0p0 << r0, t0, p0;
@@ -1552,7 +1556,7 @@ QList<QVariant> QTAIMEvaluatePropertyRTP(QList<QVariant> variantList)
     ode.setBetaSpheres(betaSpheres);
 
     QVector3D endpoint = ode.integrate(QVector3D(x0, y0, z0));
-// QList<QVector3D> path=ode.path();
+    // QList<QVector3D> path=ode.path();
 
 #define HUGE_REAL_NUMBER 1.e20
     qreal smallestDistance = HUGE_REAL_NUMBER;
@@ -1590,7 +1594,7 @@ QList<QVariant> QTAIMEvaluatePropertyRTP(QList<QVariant> variantList)
             r0 * r0 * sin(t0) *
             eval.electronDensity(Eigen::Vector3d(x0, y0, z0))
 
-              );
+          );
         } else {
           qDebug() << "mode not defined";
           qreal zero = 0.0;
@@ -1687,7 +1691,7 @@ void property_v_rtp(unsigned int /* ndim */, unsigned int npts,
   dialog.setWindowTitle("QTAIM");
   dialog.setLabelText(QString("Atomic Basin Integration"));
 
-  QFutureWatcher<void> futureWatcher;
+  QFutureWatcher<QList<QVariant>> futureWatcher;
   QObject::connect(&futureWatcher, SIGNAL(finished()), &dialog, SLOT(reset()));
   QObject::connect(&dialog, SIGNAL(canceled()), &futureWatcher, SLOT(cancel()));
   QObject::connect(&futureWatcher, SIGNAL(progressRangeChanged(int, int)),
@@ -1849,7 +1853,7 @@ QList<QVariant> QTAIMEvaluatePropertyTP(QList<QVariant> variantList)
     counter++;
     basinList.append(basin);
   }
-  QSet<qint64> basinSet = basinList.toSet();
+  QSet<qint64> basinSet(basinList.begin(), basinList.end());
 
   QTAIMWavefunction wfn;
   wfn.loadFromBinaryFile(wfnFileName);
@@ -2167,7 +2171,7 @@ void property_v_tp(unsigned int /* ndim */, unsigned int npts,
   dialog.setWindowTitle("QTAIM");
   dialog.setLabelText(QString("Atomic Basin Integration"));
 
-  QFutureWatcher<void> futureWatcher;
+  QFutureWatcher<QList<QVariant>> futureWatcher;
   QObject::connect(&futureWatcher, SIGNAL(finished()), &dialog, SLOT(reset()));
   QObject::connect(&dialog, SIGNAL(canceled()), &futureWatcher, SLOT(cancel()));
   QObject::connect(&futureWatcher, SIGNAL(progressRangeChanged(int, int)),
@@ -2386,4 +2390,4 @@ QString QTAIMCubature::temporaryFileName()
   return tempFileName;
 }
 
-} // end namespace Avogadro
+} // namespace Avogadro::QtPlugins
