@@ -231,9 +231,7 @@ void QTAIMLSODAIntegrator::f(int neq, double t, double* y, double* ydot)
       break;
   }
 
-  qreal normGradient =
-    sqrt(gradient(0) * gradient(0) + gradient(1) * gradient(1) +
-         gradient(2) * gradient(2));
+  qreal normGradient = std::hypot(gradient(0), gradient(1), gradient(2));
 
   ydot[1] = gradient(0) / normGradient;
   ydot[2] = gradient(1) / normGradient;
@@ -1021,7 +1019,7 @@ void QTAIMLSODAIntegrator::lsoda(int neq, double* y, double* t, double tout,
         return;
       }
     } /*   end else   */ /*   end iopt = 1   */
-  }                      /*   end if ( *istate == 1 || *istate == 3 )   */
+  } /*   end if ( *istate == 1 || *istate == 3 )   */
   /*
    If *istate = 1, meth is initialized to 1.
 
@@ -1125,7 +1123,7 @@ void QTAIMLSODAIntegrator::lsoda(int neq, double* y, double* t, double tout,
         return;
       }
     } /*   end for   */
-  }   /*   end if ( *istate == 1 || *istate == 3 )   */
+  } /*   end if ( *istate == 1 || *istate == 3 )   */
   /*
    If *istate = 3, set flag to signal parameter changes to stoda.
 */
@@ -1355,7 +1353,7 @@ void QTAIMLSODAIntegrator::lsoda(int neq, double* y, double* t, double tout,
           jstart = -2;
         break;
     } /*   end switch   */
-  }   /*   end if ( *istate == 2 || *istate == 3 )   */
+  } /*   end if ( *istate == 2 || *istate == 3 )   */
 
   /*
    Block e.
@@ -1557,7 +1555,7 @@ void QTAIMLSODAIntegrator::lsoda(int neq, double* y, double* t, double tout,
       terminate2(y, t);
       return;
     } /*   end if ( kflag == -1 || kflag == -2 )   */
-  }   /*   end while   */
+  } /*   end while   */
 
 } /*   end lsoda   */
 
@@ -1899,8 +1897,8 @@ void QTAIMLSODAIntegrator::stoda(int neq, double* y)
           continue;
         }
       } /*   end else -- kflag <= -3 */
-    }   /*   end error failure handling   */
-  }     /*   end outer while   */
+    } /*   end error failure handling   */
+  } /*   end outer while   */
 
 } /*   end stoda   */
 
@@ -2753,4 +2751,4 @@ void QTAIMLSODAIntegrator::freevectors()
   free(ipvt);
 } /*   end freevectors   */
 
-} // namespace Avogadro
+} // namespace Avogadro::QtPlugins
