@@ -1,24 +1,12 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "groupnode.h"
 #include "visitor.h"
 
-namespace Avogadro {
-namespace Rendering {
+namespace Avogadro::Rendering {
 
 GroupNode::GroupNode(GroupNode* parent_)
 {
@@ -35,8 +23,8 @@ GroupNode::~GroupNode()
 void GroupNode::accept(Visitor& visitor)
 {
   visitor.visit(*this);
-  for (auto it = m_children.begin(); it != m_children.end(); ++it) {
-    it->node->accept(visitor);
+  for (auto& it : m_children) {
+    it.node->accept(visitor);
   }
 }
 
@@ -46,7 +34,7 @@ void GroupNode::addChild(Node* node, NodeType ui)
     return;
   if (!hasChild(node)) {
     node->setParent(this);
-    m_children.push_back(NodeInfo(node, ui));
+    m_children.emplace_back(node, ui);
   }
 }
 
@@ -54,8 +42,8 @@ bool GroupNode::hasChild(Node* node) const
 {
   if (!node)
     return false;
-  for (auto it = m_children.begin(); it != m_children.end(); ++it) {
-    if (it->node == node) {
+  for (auto it : m_children) {
+    if (it.node == node) {
       return true;
     }
   }
@@ -129,5 +117,4 @@ void GroupNode::clearUI()
   clear(UI);
 }
 
-} // End namespace Rendering
-} // End namespace Avogadro
+} // namespace Avogadro::Rendering
