@@ -23,7 +23,7 @@ TEST(MdlTest, readFile)
   MdlFormat mdl;
   Molecule molecule;
   bool success =
-    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/ethane.mol", molecule);
+    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/sdf/ethane.mol", molecule);
   EXPECT_TRUE(success);
   EXPECT_EQ(mdl.error(), "");
   EXPECT_EQ(molecule.data("name").type(), Variant::String);
@@ -35,7 +35,7 @@ TEST(MdlTest, atoms)
   MdlFormat mdl;
   Molecule molecule;
   bool success =
-    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/ethane.mol", molecule);
+    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/sdf/ethane.mol", molecule);
   EXPECT_TRUE(success);
   EXPECT_EQ(mdl.error(), "");
   EXPECT_EQ(molecule.data("name").toString(), "Ethane");
@@ -60,7 +60,7 @@ TEST(MdlTest, bonds)
   MdlFormat mdl;
   Molecule molecule;
   bool success =
-    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/ethane.mol", molecule);
+    mdl.readFile(std::string(AVOGADRO_DATA) + "/data/sdf/ethane.mol", molecule);
   EXPECT_TRUE(success);
   EXPECT_EQ(mdl.error(), "");
   EXPECT_EQ(molecule.data("name").toString(), "Ethane");
@@ -81,8 +81,8 @@ TEST(MdlTest, saveFile)
 {
   MdlFormat mdl;
   Molecule savedMolecule, molecule;
-  bool success = mdl.readFile(std::string(AVOGADRO_DATA) + "/data/ethane.mol",
-                              savedMolecule);
+  bool success = mdl.readFile(
+    std::string(AVOGADRO_DATA) + "/data/sdf/ethane.mol", savedMolecule);
   EXPECT_TRUE(success);
   EXPECT_EQ(mdl.error(), "");
 
@@ -111,7 +111,7 @@ TEST(MdlTest, saveFile)
 TEST(MdlTest, readMulti)
 {
   MdlFormat multi;
-  multi.open(AVOGADRO_DATA "/data/multi.sdf",
+  multi.open(AVOGADRO_DATA "/data/sdf/multi.sdf",
              FileFormat::Read | FileFormat::MultiMolecule);
   Molecule molecule;
 
@@ -148,7 +148,7 @@ TEST(MdlTest, readMulti)
 TEST(MdlTest, writeMulti)
 {
   MdlFormat multi;
-  multi.open(AVOGADRO_DATA "/data/multi.sdf",
+  multi.open(AVOGADRO_DATA "/data/sdf/multi.sdf",
              FileFormat::Read | FileFormat::MultiMolecule);
   Molecule mol[2];
 
@@ -181,7 +181,7 @@ TEST(MdlTest, writeMulti)
 TEST(MdlTest, readSdfData)
 {
   MdlFormat multi;
-  multi.open(AVOGADRO_DATA "/data/pubchem3.sdf",
+  multi.open(AVOGADRO_DATA "/data/sdf/pubchem3.sdf",
              FileFormat::Read | FileFormat::MultiMolecule);
   Molecule mol[2];
   EXPECT_TRUE(multi.readMolecule(mol[0]));
