@@ -25,6 +25,7 @@
 using Avogadro::MoleQueue::InputGeneratorWidget;
 using Avogadro::QtGui::FileBrowseWidget;
 using Avogadro::QtGui::Molecule;
+using namespace std::string_literals;
 
 namespace {
 
@@ -60,7 +61,7 @@ TEST(InputGeneratorWidgetTest, exercise)
 
   // Check that the generator is configured properly.
   EXPECT_EQ(widget.inputGenerator().displayName().toStdString(),
-            std::string("Input Generator Test"));
+            "Input Generator Test"s);
 
   // Verify that appropriate widgets are produced for each parameter type:
   EXPECT_TRUE(widget.findChild<QComboBox*>("Test StringList") != nullptr);
@@ -106,10 +107,10 @@ TEST(InputGeneratorWidgetTest, exercise)
   flushEvents();
   EXPECT_TRUE(testFilePathWidget->fileName().isEmpty());
   EXPECT_EQ(filePathEdit->document()->toPlainText().toStdString(),
-            std::string("Reference file '' does not exist."));
+            "Reference file '' does not exist."s);
 
   // Test the autogenerated title:
   QLineEdit* titleEdit = widget.findChild<QLineEdit*>("Title");
   EXPECT_EQ(titleEdit->placeholderText().toStdString(),
-            std::string("CHO | Equilibrium Geometry | B3LYP/6-31G(d)"));
+            "CHO | Equilibrium Geometry | B3LYP/6-31G(d)"s);
 }
