@@ -10,6 +10,7 @@
 #include <QtCore/QListIterator>
 
 using Avogadro::MoleQueue::MoleQueueQueueListModel;
+using namespace std::string_literals;
 
 // Allow access to protected members (like ctor, setQueueList)
 class MoleQueueQueueListModelTestBridge
@@ -82,7 +83,7 @@ TEST(MoleQueueQueueListModelTest, findQueueIndices)
   EXPECT_EQ(1, matches.size());
   EXPECT_EQ(
     model.data(matches.front(), Qt::DisplayRole).toString().toStdString(),
-    std::string("Queue 7"));
+    "Queue 7"s);
 }
 
 TEST(MoleQueueQueueListModelTest, findProgramIndices)
@@ -97,7 +98,7 @@ TEST(MoleQueueQueueListModelTest, findProgramIndices)
   EXPECT_EQ(1, matches.size());
   EXPECT_EQ(
     model.data(matches.front(), Qt::DisplayRole).toString().toStdString(),
-    std::string("Q7P2"));
+    "Q7P2"s);
 
   // All 10 queues should have a program #2:
   matches = model.findProgramIndices("P2");
@@ -125,6 +126,6 @@ TEST(MoleQueueQueueListModelTest, lookupProgram)
   QString queue;
   QString program;
   EXPECT_TRUE(model.lookupProgram(matches.front(), queue, program));
-  EXPECT_EQ(std::string("Queue 7"), queue.toStdString());
-  EXPECT_EQ(std::string("Q7P2"), program.toStdString());
+  EXPECT_EQ("Queue 7"s, queue.toStdString());
+  EXPECT_EQ("Q7P2"s, program.toStdString());
 }
