@@ -125,7 +125,7 @@ int main(int argc, char* argv[])
           output << "ResidueData " << currResidue << "Data(\"" << currResidue
                  << "\",\n"
                  << "// Atoms\n{";
-          int i = 0;
+          size_t i = 0;
           for (i = 0; i < atoms.size(); ++i) {
             output << "\"" << atoms[i] << "\"";
             if (i != atoms.size() - 1)
@@ -178,7 +178,7 @@ int main(int argc, char* argv[])
   }
 
   output << "std::map<std::string, ResidueData> residueDict = {\n";
-  for (int j = 0; j < residueClassNames.size(); ++j) {
+  for (size_t j = 0; j < residueClassNames.size(); ++j) {
     output << "{\"" << residueClassNames[j] << "\", " << residueClassNames[j]
            << "Data}";
     if (j != residueClassNames.size() - 1)
